// datatableadapter.js


/**
 * @class public DataTableAdapter
 * @constructor DataTableAdapter
 * 	 This class binds the datatable to xmldata 
 * @param String table
 *	 The id of the table
 * @param XML2EMF xmlBinderArray[]
 *	 The array of xmlbinders the table is bound to. 
 **/
function DataTableAdapter(tableId, xmlBinder, attributeName)
{
	this.tableId = tableId;
	this.columnIds = new Array();
	this.xmlBinder = xmlBinder;
	this.xmlBinderArray = new Array();
	this.columnNames = new Array();
	this.columnTypes = new Array();
	this.attributeName = attributeName;
	// set up the array of xmlbinders for the rows
	this.xmlBinderArray = this.xmlBinder.eGet(this.attributeName); 
	
	this.parentPropertyBinder = null;
	this.activeBinders = new Array;
	
	this.activateDataSet();
	
}


/**
 * @method public DataTableAdapter.prototype.addColumn
 * 	This method adds a column to the datatable
 * @param String columnId
 *	The id of the column.
 * @param String columnAttributeName
 *	The attribute this column is bound to.
 * @param String columnType
 *	The type of control in this column,
 *  ie input or output..
 **/
DataTableAdapter.prototype.addColumn = function(columnId, columnAttributeName, columnType)
{
	this.columnIds[this.columnIds.length] = columnId;
	this.columnNames[columnId] = columnAttributeName;
	this.columnTypes[columnId] = columnType;
}

/**
 * @method public DataTableAdapter.prototype.bind
 * 	This binds the datatable to the adapters.
 **/
DataTableAdapter.prototype.bind = function()
{
 	var i, j;
 	
 	// We need to size the number of rows on the table to
 	// the  data size.
	var tableBody = document.getElementById(this.tableId).tBodies[0];
	if (tableBody.rows.length > this.xmlBinderArray.length)
	{
		for ( i=this.xmlBinderArray.length; i<tableBody.rows.length; i++ )
		{
			tableBody.removeChild(tableBody.rows[i]);		
		}
		
	}
 	
 	
 	for ( i=0; i<this.xmlBinderArray.length; i++ )
 	{	
 	
 		
 		// If the row for this data doesn't exist create it 
 		// from the first row. This assumes that a row has been
 		// output to the page.
 		if (document.getElementById(this.tableId+":"+i+":"+this.columnIds[0]) == null )
 		{
 			var theTable = document.getElementById(this.tableId).tBodies[0];
 			var newRow = theTable.rows[0].cloneNode(true);
 			
 			for( j=0; j<this.columnIds.length; j++)
 			{	 	 
 				
 				newRow.cells[j].firstChild.id = this.tableId+":"+i+":"+this.columnIds[j];
 			}
 			theTable.appendChild(newRow);
 						
 		}
 	
 		for( j=0; j<this.columnIds.length; j++)
 		{	
 			// this will get the id of the control within the datatable
 			// in the form of form1:table1:0:text1
 			var cellId = this.tableId+":"+i+":"+this.columnIds[j];
 			if (this.columnTypes[this.columnIds[j]] == "output")
 			{
 				var element = document.getElementById(cellId).firstChild;
 				var value = "nodeValue";
 			}
 			else {
 				var element = document.getElementById(cellId);
 				var value = "value";
 			}
		 	var PropertyBinderAdapter = new PropertyBinder(this.xmlBinderArray[i],this.columnNames[this.columnIds[j]],element,value,'onblur');
			PropertyBinderAdapter.DataBind();
			this.activeBinders[this.activeBinders.length] = PropertyBinderAdapter;
			
			
			ODCRegistry.addElementInfo('_id1',cellId,cellId,PropertyBinderAdapter); 
		}	
 	}
}

/**
 * @method public DataTableAdapter.prototype.activateDataSet
 * 	This method changes the root object that the table is bound to.
 * @param XML2EMF eobject
 *	The new data object that the table should be bound to.
 **/ 
DataTableAdapter.prototype.activateDataSet = function(eobject)
{
 
 	if (eobject)
 	{
	 	this.xmlBinder = eobject;
	 	this.xmlBinderArray = eobject.eGet(this.attributeName); 
 	}
 	
 	for (var i=0; i<this.activeBinders.length; i++)
 	{
 		this.activeBinders[i].DataUnbind();
	}
 	
 	if (null != this.parentPropertyBinder ) {

		this.xmlBinder.PropertyBinders.Remove(this.parentPropertyBinder);

	}
 	
 	var pb = new PropertyBinder(this.xmlBinder,this.attributeName,this);
 	pb.ControlSetFunction = "onModelChange";
	
	this.parentPropertyBinder = this.xmlBinder.PropertyBinders.Add(pb);
 	
 	
 
}


/**
 * @method public DataTableAdapter.prototype.refresh
 * 	This method refreshes the drawing of the datatable with the
 *  the data it is currently bound to. This usually occurs after 
 *  activateDataSet is called.
 **/  
DataTableAdapter.prototype.refresh = function()
{
	this.bind();
 
}
 
 /**
* @method private DataTableAdapter.prototype.onModelChange
*   this function will be fired by the Eobject when there is a change
*   relating to the "propertyName"
* @param boolean rows
*	if rows is true, then rebind to the new parent eobject.
**/
DataTableAdapter.prototype.onModelChange = function(rows)
{
	  if (rows) {

				this.activateDataSet(this.xmlBinder);
				this.refresh();
	  }

}
 
 